@@ -249,6 +249,8 @@ def _multiframe_to_nifti(dicom_input, output_file):
     # Save to disk
     if output_file is not None:
         logger.info('Saving nifti to disk %s' % output_file)
+        nii_image.header.set_slope_inter(1, 0)
+        nii_image.header.set_xyzt_units(2)  # set units for xyz (leave t as unknown)
         nii_image.to_filename(output_file)
 
     if _is_multiframe_diffusion_imaging(dicom_input):
@@ -296,6 +298,8 @@ def _singleframe_to_nifti(grouped_dicoms, output_file):
     if output_file is not None:
         # Save to disk
         logger.info('Saving nifti to disk %s' % output_file)
+        nii_image.header.set_slope_inter(1, 0)
+        nii_image.header.set_xyzt_units(2)  # set units for xyz (leave t as unknown)
         nii_image.to_filename(output_file)
 
     if _is_singleframe_diffusion_imaging(grouped_dicoms):
@@ -567,6 +571,8 @@ def _fix_diffusion_images(bvals, bvecs, nifti, nifti_file):
 
     # remove last elements from the nifti
     new_nifti = nibabel.Nifti1Image(common.get_nifti_data(nifti)[:, :, :, :-1].squeeze(), nifti.affine)
+    new_nifti.header.set_slope_inter(1, 0)
+    new_nifti.header.set_xyzt_units(2)  # set units for xyz (leave t as unknown)
     new_nifti.to_filename(nifti_file)
 
     return new_nifti, bvals, bvecs
